import iam = require('@aws-cdk/aws-iam');
import cdk = require('@aws-cdk/cdk');
import { ILogGroup } from './log-group';
import { ILogSubscriptionDestination, LogSubscriptionDestination } from './subscription-filter';
export interface CrossAccountDestinationProps {
    /**
     * The name of the log destination.
     *
     * @default Automatically generated
     */
    readonly destinationName?: string;
    /**
     * The role to assume that grants permissions to write to 'target'.
     *
     * The role must be assumable by 'logs.{REGION}.amazonaws.com'.
     */
    readonly role: iam.Role;
    /**
     * The log destination target's ARN
     */
    readonly targetArn: string;
}
/**
 * A new CloudWatch Logs Destination for use in cross-account scenarios
 *
 * Log destinations can be used to subscribe a Kinesis stream in a different
 * account to a CloudWatch Subscription. A Kinesis stream in the same account
 * can be subscribed directly.
 *
 * The @aws-cdk/aws-kinesis library takes care of this automatically; you shouldn't
 * need to bother with this class.
 */
export declare class CrossAccountDestination extends cdk.Construct implements ILogSubscriptionDestination {
    /**
     * Policy object of this CrossAccountDestination object
     */
    readonly policyDocument: iam.PolicyDocument;
    /**
     * The name of this CrossAccountDestination object
     */
    readonly destinationName: string;
    /**
     * The ARN of this CrossAccountDestination object
     */
    readonly destinationArn: string;
    /**
     * The inner resource
     */
    private readonly resource;
    constructor(scope: cdk.Construct, id: string, props: CrossAccountDestinationProps);
    addToPolicy(statement: iam.PolicyStatement): void;
    logSubscriptionDestination(_sourceLogGroup: ILogGroup): LogSubscriptionDestination;
    /**
     * Generate a unique Destination name in case the user didn't supply one
     */
    private generateUniqueName;
    /**
     * Return a stringified JSON version of the PolicyDocument
     */
    private lazyStringifiedPolicyDocument;
}
